@@ -14,6 +14,9 @@ class BaseFamily():
         self.marriage = None
         self.location = None
 
+    def __repr__(self):
+        return 'family "' + self.husb_name + '"+"' + self.wife_name + '"'
+
     def _initialize(self):
         self.husband_individual_id, self.wife_individual_id = self._get_husband_and_wife_id()
         self.children_individual_ids = self._get_children_ids()
@@ -72,7 +75,12 @@ class BaseFamily():
         Returns:
             list: list of children instances
         """
-        return [self._instances[('i', id)] for id in self.children_individual_ids]
+        children = []
+        for id in self.children_individual_ids:
+            child = self._instances[('i', id)]
+            if child:
+                children.append(child)
+        return children
     """
     children BaseIndividual instances
     """
