@@ -1,9 +1,5 @@
 import logging
-from .ReadGedcom import read_data
-import os
-import json
-from .GedcomIndividual import GedcomIndividual
-from .GedcomFamily import GedcomFamily
+from .Exceptions import LifeLineChartNotEnoughInformationToDisplay
 
 logging.basicConfig()  # level=20)
 logger = logging.getLogger("life_line_chart")
@@ -67,13 +63,21 @@ class InstanceContainer():
         elif key[0] == 'i':
             item = self._data.get(key)
             if item is None:
-                self._data[key] = self._individual_constructor(self, key)
-            return self._data[key]
+                try:
+                    item = self._individual_constructor(self, key)
+                    self._data[key] = item
+                except LifeLineChartNotEnoughInformationToDisplay:
+                    item = None
+            return item
         elif key[0] == 'f':
             item = self._data.get(key)
             if item is None:
-                self._data[key] = self._family_constructor(self, key)
-            return self._data[key]
+                try:
+                    item = self._family_constructor(self, key)
+                    self._data[key] = item
+                except LifeLineChartNotEnoughInformationToDisplay:
+                    item = None
+            return item
         return None
 
     def __setitem__(self, key, value):
@@ -86,49 +90,3 @@ class InstanceContainer():
         self._data.clear()
         self._data.update({('i', None): None, ('f', None): None})
 
-
-def get_gedcom_instance_container(filename='gramps_testdata.ged'):
-    """
-    instance container for families and individuals from gedcom file
-
-    Args:
-        filename (str, optional): gedcom file. Defaults to 'gramps_testdata.ged'.
-
-    Returns:
-        InstanceContainer: instance container
-    """
-    logger.debug('start reading data')
-    if True:
-        if filename:
-            # read gedcom and write json
-            database_indi, database_fam = read_data(filename)
-            # self.database_indi, self.database_fam = read_data('--- febr. 2015.ged')
-            # open(os.path.join('..', os.path.dirname(__file__), 'indi.json'),'w').write(json.dumps(database_indi))
-            # open(os.path.join('..', os.path.dirname(__file__), 'fam.json'),'w').write(json.dumps(database_fam))
-        else:
-            database_indi = {}
-            database_fam = {}
-    else:
-        # read json
-        database_indi = json.loads(
-            open(os.path.join('..', os.path.dirname(__file__), 'indi.json'), 'r').read())
-        database_fam = json.loads(
-            open(os.path.join('..', os.path.dirname(__file__), 'fam.json'), 'r').read())
-
-    def instantiate_all(self, database_fam, database_indi):
-        for family_id in list(database_fam.keys()):
-            if not ('f', family_id) in self:
-                self[('f', family_id)] = GedcomFamily(
-                    self, database_fam, database_indi, family_id)
-        for individual_id in list(database_indi.keys()):
-            if not ('i', individual_id) in self:
-                self[('i', individual_id)] = GedcomIndividual(
-                    self, database_fam, database_indi, individual_id)
-
-    logger.debug('start creating instances')
-    return InstanceContainer(
-        lambda self, key: GedcomFamily(
-            self, database_fam, database_indi, key[1]),
-        lambda self, key: GedcomIndividual(
-            self, database_fam, database_indi, key[1]),
-        lambda self: instantiate_all(self, database_fam, database_indi))
